# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sas7bdat_converter']

package_data = \
{'': ['*']}

install_requires = \
['pandas==1.2.0']

extras_require = \
{'excel': ['openpyxl>=3.0.5,<4.0.0']}

setup_kwargs = {
    'name': 'sas7bdat-converter',
    'version': '0.8.0',
    'description': 'Convert sas7bdat and xport files into other formats',
    'long_description': '# sas7bdat_converter: Convert sas7bdat files into other formats\n\n[![Tests Status](https://github.com/sanders41/sas7bdat_converter/workflows/Tests/badge.svg?branch=master&event=push)](https://github.com/sanders41/sas7bdat_converter/actions?query=workflow%3ATests+branch%3Amaster+event%3Apush)\n[![Lint Status](https://github.com/sanders41/sas7bdat_converter/workflows/Linting/badge.svg?branch=master&event=push)](https://github.com/sanders41/sas7bdat_converter/actions?query=workflow%3ALinting+branch%3Amaster+event%3Apush)\n[![Coverage](https://codecov.io/github/sanders41/sas7bdat_converter/coverage.svg?branch=master)](https://codecov.io/gh/sanders41/sas7bdat_converter)\n\n\nConverts proprietary sas7bdat and/or xport files from SAS into formats such as csv and XML useable\nby other programs. Currently supported conversiaions are csv, Excel (xlsx format), json, Pandas\nDataFrame, and XML.\n\nConversions can be done on either a single file, an entire directory, or a batch of specified files.\n\n## Install\n`pip install sas7bdat_converter`\n\nIf you would like to be able to convert to Excel files you will need to install with the extra Excel dependency.\n\n`pip install sas7bdat_converter[excel]`\n\n## Usage\n\nIn all cases either sas7bdat or xport files can be converted. Examples below all use the .sas7bdat\nextension, xport files with a .xpt extension will also work.\n\n* **batch_to_csv(file_dicts)** - Convert multiple sas7bdat files into csv files at once.\n  * file_dicts = A list containing a dictionary for each file to convert. The dictionary is required\n  to contain \'sas7bdat_file\' containing the path and name for the sas7bdat file, and \'export_file\'\n  containing the path and name for the csv files. The csv file extension should be .csv. File paths\n  can be sent as either strings or Path objects.\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  file_dicts = [\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_1.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_1.csv\',\n    },\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_2.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_2.csv\',\n    },\n  ]\n  sas7bdat_converter.batch_to_csv(file_dicts)\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example_1.sas7bdat`.\n\n* **batch_to_excel(file_dicts)** - Convert multiple sas7bdat files into Excel files at once.\n  * file_dicts = A list containing a dictionary for each file to convert. The dictionary is required\n  to contain \'sas7bdat_file\' containing the path and name for the sas7bdat file, and \'export_file\'\n  containing the path and name for the excel files. The Excel file extension should be .xlsx. File\n  paths can be sent as either strings or Path objects.\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  file_dicts = [\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_1.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_1.xlsx\',\n    },\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_2.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_2.xlsx\',\n    },\n  ]\n  sas7bdat_converter.batch_to_excel(file_dicts)\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example_1.sas7bdat`.\n\n* **batch_to_json(file_dicts)** - Convert multiple sas7bdat files into json files at once.\n  * file_dicts = A list containing a dictionary for each file to convert. The dictionary is required\n  to contain \'sas7bdat_file\' containing the path and name for the sas7bdat file, and \'export_file\'\n  containing the path and name for the json files. The json file extension should be .json. File\n  paths can be sent as either strings or Path objects.\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  file_dicts = [\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_1.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_1.json\',\n    },\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_2.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_2.json\',\n    },\n  ]\n  sas7bdat_converter.batch_to_json(file_dicts)\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example_1.sas7bdat`.\n\n* **batch_to_xml(file_dicts)** - Convert multiple sas7bdat files into XML files at once.\n  * file_dicts = A list containing a dictionary for each file to convert. The dictionary is required\n  to contain \'sas7bdat_file\' containing the path and name for the sas7bdat file, and \'export_file\'\n  containing the path and name for the xml files. The XML file extension should be .xml. File paths\n  can be sent as either strings or Path objects.\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converters\n\n  file_dicts = [\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_1.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_1.xml\',\n    },\n    {\n      \'sas7bdat_file\': \'/path/to/sas7bdat/files/example_2.sas7bdat\',\n      \'export_file\': \'/path/to/new/files/example_2.xml\',\n    },\n  ]\n  sas7bdat_converter.batch_to_xml(file_dicts)\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example_1.sas7bdat`.\n\n* **dir_to_csv(dir_path, export_path=None)** - Convert all sas7bdat files in a directory into csv\nfiles at once. File paths can be sent as either strings or Path objects.\n  * dir_path = The dictionary that contains the sas7bdat file to convert.\n  * export_path = Optional path for the converted files. If no path is supplied the new files will\n  be put into the dir_path directory with the sas7bdat files. File paths can be sent as either\n  strings or Path objects. Default = None\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  # Option 1: put the converted files in the same directory as the sas7bdat files\n  sas7bdat_converter.dir_to_csv(\'/path/to/sas7bdat/files\')\n\n  # Option 2: put the converted fiels in a diffferent directory\n  sas7bdat_converter.dir_to_csv(\'/path/to/sas7bdat/files\', \'path/for/new/files\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files`.\n\n* **dir_to_excel(dir_path, export_path=None)** - Convert all sas7bdat files in a directory into\nExcel files at once. File paths can be sent as either strings or Path objects.\n  * dir_path = The dictionary that contains the sas7bdat file to convert.\n  * export_path = Optional path for the converted files. If no path is supplied the new files will\n  be put into the dir_path directory with the sas7bdat files Default = None\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  # Option 1: put the converted files in the same directory as the sas7bdat files\n  sas7bdat_converter.dir_to_excel(\'/path/to/sas7bdat/files\')\n\n  # Option 2: put the converted fiels in a diffferent directory\n  sas7bdat_converter.dir_to_excel(\'/path/to/sas7bdat/files\', \'path/for/new/files\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files`.\n\n* **dir_to_json(dir_path, export_path=None)** - Convert all sas7bdat files in a directory into json\n  files at once. File paths can be sent as either strings or Path objects.\n  * dir_path = The dictionary that contains the sas7bdat file to convert.\n  * export_path = Optional path for the converted files. If no path is supplied the new files will\n  be put into the dir_path directory with the sas7bdat files. Default = None\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  # Option 1: put the converted files in the same directory as the sas7bdat files\n  sas7bdat_converter.dir_to_json(\'/path/to/sas7bdat/files\')\n\n  # Option 2: put the converted fiels in a diffferent directory\n  sas7bdat_converter.dir_to_json(\'/path/to/sas7bdat/files\', \'path/for/new/files\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files`.\n\n* **dir_to_xml(dir_path, export_path=None)** - Convert all sas7bdat files in a directory into XML\n  files at once. File paths can be sent as either strings or Path objects.\n  * dir_path = The dictionary that contains the sas7bdat file to convert.\n  * export_path = Optional path for the converted files. If no path is supplied the new files will\n  be put into the dir_path directory with the sas7bdat files. Default = None\n  * continue_on_error = If set to true processing of files in a batch will continue if there is a\n  file conversion error instead of raising an exception. Default = False\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  # Option 1: put the converted files in the same directory as the sas7bdat files\n  sas7bdat_converter.dir_to_xml(\'/path/to/sas7bdat/files\')\n\n  # Option 2: put the converted fiels in a diffferent directory\n  sas7bdat_converter.dir_to_xml(\'/path/to/sas7bdat/files\', \'path/for/new/files\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files`.\n\n* **to_csv(sas7bdat_file, export_file)** - convert a sas7bdat file into a csv file. File path can be\n  sent as either a string or Path objects.\n  * sas7bdat_file = the path and name for sas7bdat file to convert.\n  * export_file = the path and name for the csv file. The csv file extension should be .csv.\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  sas7bdat_converter.to_csv(\'/path/to/sas7bdat/file/example.sas7bdat\', \'path/to/new/file/example.csv\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example.sas7bdat`.\n\n* **to_dataframe(sas7bdat_file)** - Convert a sas7bdat file into a Pandas DataFrame. File path can\n  be sent as either a string or Path objects.\n  * sas7bdat_file = The path and name for sas7bdat file to convert.\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  sas7bdat_converter.to_dataframe(\'/path/to/sas7bdat/file/example.sas7bdat\')\n  ```\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example_1.sas7bdat`.\n\n* **to_excel(sas7bdat_file, export_file)** - convert a sas7bdat file into a Excel file. File path\n  can be sent as either a string or Path objects.\n  * sas7bdat_file = the path and name for sas7bdat file to convert.\n  * export_file = the path and name for the Excel file. The Excel file extension should be .xlsx.\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  sas7bdat_converter.to_excel(\'/path/to/sas7bdat/file/example.sas7bdat\',\n  \'path/to/new/file/example.xlsx\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example.sas7bdat`.\n\n* **to_json(sas7bdat_file, export_file)** - convert a sas7bdat file into a json file. File path can\n  be sent as either a string or Path objects.\n  * sas7bdat_file = the path and name for sas7bdat file to convert.\n  * export_file = the path and name for the json file. the json file extension should be .json.\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  sas7bdat_converter.to_json(\'/path/to/sas7bdat/file/example.sas7bdat\', \'path/to/new/file/example.json\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example.sas7bdat`.\n\n* **to_xml(sas7bdat_file, export_file, root_node=\'root\', first_node=\'item\')** - convert a sas7bdat\n  file into a XML file. File path can be sent as either a string or Path objects.\n  * sas7bdat_file = the path and name for sas7bdat file to convert.\n  * export_file = the path and name for the XML file. The XML file extension should be .xlm.\n  * root_node = The name to uses for the top level node. If no name is supplied "root" will be used.\n  * first_node = The name to use for the first node under root. If no name is supplied "item" will be used.\n\n  #### Example\n  ```\n  import sas7bdat_converter\n\n  sas7bdat_converter.to_xml(\'/path/to/sas7bdat/file/example.sas7bdat\', \'path/to/new/file/example.xml\')\n  ```\n\n  **Note:** Example uses Mac/Linux type file paths. For Windows use paths like\n  `c:\\path\\to\\sas7bdat\\files\\example.sas7bdat`.\n\n\n# Contributing\n\nIf you are interesting in contributing to this project please see our [contributing guide](CONTRIBUTING.md)\n',
    'author': 'Paul Sanders',
    'author_email': 'psanders1@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sanders41/sas7bdat_converter',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.1,<4.0.0',
}


setup(**setup_kwargs)
